@@ -1,4 +1,6 @@
 package Google::Adwords::AdGroupRequest;
+use strict;
+use warnings;
 
 use base 'Google::Adwords::Data';
 
@@ -6,7 +8,7 @@ my @fields = qw/
     id
     keywordRequests
     maxCpc
-/;
+    /;
 
 __PACKAGE__->mk_accessors(@fields);
 
@@ -53,7 +55,7 @@ Rohan Almeida <rohan@almeida.in>
 
  
  
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
  
 Copyright (c) 2006 Rohan Almeida <rohan@almeida.in>. All rights
 reserved.
