@@ -8,7 +8,6 @@ use base 'Google::Adwords::Data';
 
 my @fields = qw/
     _countries
-    _excludedCountries
     /;
 
 __PACKAGE__->mk_accessors(@fields);
@@ -64,35 +63,6 @@ sub countries
     return $self->get('_countries');
 } # end sub countries
 
-# excludedCountries should always return an array ref
-sub excludedCountries
-{
-    my $self = shift;
-
-    # if its a put
-    if (@_)
-    {
-        my $put_ref = [];
-
-        for (@_)
-        {
-            if ( ref $_ ne 'ARRAY' )
-            {
-                push @{$put_ref}, $_;
-            }
-            else
-            {
-                push @{$put_ref}, @{$_};
-            }
-        }
-
-        $self->set( '_excludedCountries', $put_ref );
-        return $self;
-    } # end if (@_)
-
-    return $self->get('_excludedCountries');
-} # end sub excludedCountries
-
 1;
 
 =pod
